==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/HTTPChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPChaosStatusFluent<A extends HTTPChaosStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,ChaosCondition item);
  public A setToConditions(Integer index,ChaosCondition item);
  public A addToConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A addAllToConditions(Collection<ChaosCondition> items);
  public A removeFromConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A removeAllFromConditions(Collection<ChaosCondition> items);
  public A removeMatchingFromConditions(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ChaosCondition> getConditions();
  public List<ChaosCondition> buildConditions();
  public ChaosCondition buildCondition(Integer index);
  public ChaosCondition buildFirstCondition();
  public ChaosCondition buildLastCondition();
  public ChaosCondition buildMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public A withConditions(List<ChaosCondition> conditions);
  public A withConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String reason,String status,String type);
  public HTTPChaosStatusFluent.ConditionsNested<A> addNewCondition();
  public HTTPChaosStatusFluent.ConditionsNested<A> addNewConditionLike(ChaosCondition item);
  public HTTPChaosStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,ChaosCondition item);
  public HTTPChaosStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public HTTPChaosStatusFluent.ConditionsNested<A> editFirstCondition();
  public HTTPChaosStatusFluent.ConditionsNested<A> editLastCondition();
  public HTTPChaosStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExperiment instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExperimentStatus getExperiment();
  public ExperimentStatus buildExperiment();
  public A withExperiment(ExperimentStatus experiment);
  public Boolean hasExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> withNewExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
  public HTTPChaosStatusFluent.ExperimentNested<A> editExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
  public A addToInstances(String key,Long value);
  public A addToInstances(Map<String,Long> map);
  public A removeFromInstances(String key);
  public A removeFromInstances(Map<String,Long> map);
  public Map<String,Long> getInstances();
  public <K,V>A withInstances(Map<String,Long> instances);
  public Boolean hasInstances();
  public interface ConditionsNested<N> extends Nested<N>,ChaosConditionFluent<HTTPChaosStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ExperimentNested<N> extends Nested<N>,ExperimentStatusFluent<HTTPChaosStatusFluent.ExperimentNested<N>>{
    public N and();
    public N endExperiment();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/HTTPChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPChaosStatusFluent<A extends HTTPChaosStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,ChaosCondition item);
  public A setToConditions(int index,ChaosCondition item);
  public A addToConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A addAllToConditions(Collection<ChaosCondition> items);
  public A removeFromConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... items);
  public A removeAllFromConditions(Collection<ChaosCondition> items);
  public A removeMatchingFromConditions(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ChaosCondition> getConditions();
  public List<ChaosCondition> buildConditions();
  public ChaosCondition buildCondition(int index);
  public ChaosCondition buildFirstCondition();
  public ChaosCondition buildLastCondition();
  public ChaosCondition buildMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  public A withConditions(List<ChaosCondition> conditions);
  public A withConditions(io.fabric8.chaosmesh.v1alpha1.ChaosCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String reason,String status,String type);
  public HTTPChaosStatusFluent.ConditionsNested<A> addNewCondition();
  public HTTPChaosStatusFluent.ConditionsNested<A> addNewConditionLike(ChaosCondition item);
  public HTTPChaosStatusFluent.ConditionsNested<A> setNewConditionLike(int index,ChaosCondition item);
  public HTTPChaosStatusFluent.ConditionsNested<A> editCondition(int index);
  public HTTPChaosStatusFluent.ConditionsNested<A> editFirstCondition();
  public HTTPChaosStatusFluent.ConditionsNested<A> editLastCondition();
  public HTTPChaosStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ChaosConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExperiment instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExperimentStatus getExperiment();
  public ExperimentStatus buildExperiment();
  public A withExperiment(ExperimentStatus experiment);
  public Boolean hasExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> withNewExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
  public HTTPChaosStatusFluent.ExperimentNested<A> editExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
  public HTTPChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
  public A addToInstances(String key,Long value);
  public A addToInstances(Map<String,Long> map);
  public A removeFromInstances(String key);
  public A removeFromInstances(Map<String,Long> map);
  public Map<String,Long> getInstances();
  public <K,V>A withInstances(Map<String,Long> instances);
  public Boolean hasInstances();
  public interface ConditionsNested<N> extends Nested<N>,ChaosConditionFluent<HTTPChaosStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface ExperimentNested<N> extends Nested<N>,ExperimentStatusFluent<HTTPChaosStatusFluent.ExperimentNested<N>>{
    public N and();
    public N endExperiment();
    
  }
  
}
